==> docstrange-1.0.1.tar.gz: docstrange-1.0.1/tests/test_real_files_enhanced.py <==
#!/usr/bin/env python3
"""
Enhanced test script for downloading sample files and testing extraction capabilities.
Uses more reliable sample file sources and provides detailed analysis.
"""

import os
import tempfile
import requests
from docstrange import DocumentExtractor


def download_sample_files():
    """Download sample files for each supported format using reliable sources."""
    print("📥 Downloading sample files for testing...")
    
    samples = {}
    
    # More reliable sample URLs
    sample_urls = {
        'pdf': 'https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf',
        'csv': 'https://raw.githubusercontent.com/datasets/gdp/master/data/gdp.csv',
        'txt': 'https://www.gutenberg.org/files/1342/1342-0.txt',  # Pride and Prejudice
        'html': 'https://raw.githubusercontent.com/mdn/learning-area/master/html/introduction-to-html/getting-started/index.html',
    }
    
    for format_type, url in sample_urls.items():
        try:
            print(f"   Downloading {format_type.upper()} sample...")
            response = requests.get(url, timeout=30)
            response.raise_for_status()
            
            # Create temporary file
            with tempfile.NamedTemporaryFile(suffix=f'.{format_type}', delete=False) as f:
                f.write(response.content)
                samples[format_type] = f.name
            
            print(f"   ✅ Downloaded {format_type.upper()}: {len(response.content)} bytes")
            
        except Exception as e:
            print(f"   ❌ Failed to download {format_type.upper()}: {e}")
    
    return samples


def create_sample_files():
    """Create additional sample files for testing."""
    print("   Creating additional sample files...")
    
    samples = {}
    
    # Create sample DOCX-like content (simulated)
    with tempfile.NamedTemporaryFile(mode='w', suffix='.txt', delete=False) as f:
        f.write("""# Business Document

## Company Overview
Our company specializes in innovative solutions for modern businesses.

## Services
- Software Development
- Cloud Solutions
- AI Integration
- Data Analytics

## Contact Information
Email: contact@company.com
Phone: +1-555-0123
Address: 123 Business St, City, State 12345

## Financial Summary
| Quarter | Revenue | Growth |
|---------|---------|--------|
| Q1 | $1.2M | 15% |
| Q2 | $1.4M | 17% |
| Q3 | $1.6M | 14% |
| Q4 | $1.8M | 12% |
        """)
        samples['docx_sim'] = f.name
    
    # Create sample Excel-like content (CSV format)
    with tempfile.NamedTemporaryFile(mode='w', suffix='.csv', delete=False) as f:
        f.write("""Department,Employee,Salary,Start_Date
Engineering,John Smith,75000,2023-01-15
Marketing,Jane Doe,65000,2023-02-01
Sales,Bob Johnson,80000,2023-01-20
HR,Alice Brown,70000,2023-03-01
Finance,Charlie Wilson,85000,2023-02-15
IT,Sarah Davis,90000,2023-01-10
        """)
        samples['excel_sim'] = f.name
    
    # Create sample PowerPoint-like content
    with tempfile.NamedTemporaryFile(mode='w', suffix='.txt', delete=False) as f:
        f.write("""# Presentation: Q4 Business Review

## Slide 1: Executive Summary
- Revenue growth: 15% YoY
- Market expansion: 3 new regions
- Product launches: 2 successful releases

## Slide 2: Financial Performance
- Total revenue: $2.5M
- Profit margin: 23%
- Customer acquisition cost: $150

## Slide 3: Key Achievements
1. Launched mobile app
2. Expanded to Europe
3. Improved customer satisfaction
4. Reduced operational costs

## Slide 4: Next Steps
- Q1: Launch new product line
- Q2: Enter Asian markets
- Q3: AI integration rollout
- Q4: IPO preparation
        """)
        samples['pptx_sim'] = f.name
    
    return samples


def test_file_extraction():
    """Test extraction capabilities on downloaded and created files."""
    print("\n🧪 Testing File Extraction Capabilities")
    print("=" * 60)
    
    extractor = DocumentExtractor()
    
    # Get downloaded samples
    downloaded_samples = download_sample_files()
    
    # Get created samples
    created_samples = create_sample_files()
    
    # Combine all samples
    all_samples = {**downloaded_samples, **created_samples}
    
    results = {}
    
    for format_type, file_path in all_samples.items():
        print(f"\n📄 Testing {format_type.upper()} extraction...")
        
        try:
            # Test basic conversion
            result = extractor.extract(file_path)
            
            # Get markdown output
            markdown = result.extract_markdown()
            
            # Analyze content
            content_analysis = analyze_content(markdown)
            
            # Store results
            results[format_type] = {
                'success': True,
                'content_length': len(result.content),
                'markdown_length': len(markdown),
                'metadata_keys': list(result.metadata.keys()),
                'content_analysis': content_analysis,
                'preview': markdown[:300] + "..." if len(markdown) > 300 else markdown
            }
            
            print(f"   ✅ {format_type.upper()} extraction successful")
            print(f"      Content length: {len(result.content)} characters")
            print(f"      Markdown length: {len(markdown)} characters")
            print(f"      Metadata keys: {len(result.metadata)} items")
            print(f"      Content analysis: {content_analysis}")
            
            # Show preview
            print(f"      Preview: {markdown[:100]}...")
            
        except Exception as e:
            results[format_type] = {
                'success': False,
                'error': str(e)
            }
            print(f"   ❌ {format_type.upper()} extraction failed: {e}")
        
        finally:
            # Clean up file
            if os.path.exists(file_path):
                os.unlink(file_path)
    
    return results


def analyze_content(markdown_content):
    """Analyze the content structure of the markdown."""
    analysis = {}
    
    # Count different elements
    analysis['lines'] = len(markdown_content.split('\n'))
    analysis['words'] = len(markdown_content.split())
    analysis['headers'] = markdown_content.count('#')
    analysis['lists'] = markdown_content.count('- ') + markdown_content.count('* ')
    analysis['tables'] = markdown_content.count('|')
    analysis['links'] = markdown_content.count('[')
    
    # Determine content type
    if analysis['tables'] > 10:
        analysis['type'] = 'structured_data'
    elif analysis['headers'] > 5:
        analysis['type'] = 'document'
    elif analysis['lists'] > 5:
        analysis['type'] = 'list_content'
    else:
        analysis['type'] = 'text'
    
    return analysis


def test_markdown_quality():
    """Test the quality of markdown output."""
    print("\n📝 Testing Markdown Quality")
    print("=" * 60)
    
    extractor = DocumentExtractor()
    
    # Test with different content types
    test_contents = [
        ("Simple text", "This is a simple text document."),
        ("Text with headers", "# Header 1\n## Header 2\nThis is content."),
        ("Text with lists", "- Item 1\n- Item 2\n- Item 3"),
        ("Text with table", "| Col1 | Col2 |\n|------|------|\n| Data | Data |"),
    ]
    
    for content_name, content in test_contents:
        print(f"\n   Testing: {content_name}")
        
        try:
            result = extractor.convert_text(content)
            markdown = result.extract_markdown()
            
            print(f"      Original: {len(content)} chars")
            print(f"      Markdown: {len(markdown)} chars")
            print(f"      Quality: {'✅ Good' if markdown.strip() == content.strip() else '⚠️  Modified'}")
            
        except Exception as e:
            print(f"      ❌ Failed: {e}")


def test_llm_integration_ready():
    """Test if the output is ready for LLM integration."""
    print("\n🤖 Testing LLM Integration Readiness")
    print("=" * 60)
    
    extractor = DocumentExtractor()
    
    # Create a sample business document
    sample_doc = """# Quarterly Business Report

## Executive Summary
This report covers Q4 2024 performance and strategic initiatives.

## Financial Performance
- Revenue: $2.5M (15% increase)
- Profit Margin: 23%
- Customer Growth: 45%

## Key Metrics
| Metric | Q3 | Q4 | Growth |
|--------|----|----|--------|
| Revenue | $2.1M | $2.5M | 19% |
| Users | 15K | 22K | 47% |
| Retention | 85% | 89% | 4% |

## Recommendations
1. Expand marketing budget
2. Improve customer support
3. Launch new product line
    """
    
    try:
        result = extractor.convert_text(sample_doc)
        markdown = result.extract_markdown()
        
        print("   ✅ Document converted to LLM-ready format")
        print(f"   Content length: {len(markdown)} characters")
        
        # Test LLM integration example
        print("\n   📋 LLM Integration Example:")
        print("   ```python")
        print("   from litellm import completion")
        print("   ")
        print("   response = completion(")
        print("       model=\"openai/gpt-4o\",")
        print("       messages=[")
        print("           {\"role\": \"system\", \"content\": \"You are a business analyst.\"},")
        print("           {\"role\": \"user\", \"content\": f\"Analyze this report:\\n\\n{markdown}\"}")
        print("       ]")
        print("   )")
        print("   ")
        print("   print(response.choices[0].message.content)")
        print("   ```")
        
    except Exception as e:
        print(f"   ❌ LLM integration test failed: {e}")


def generate_detailed_report(results):
    """Generate a detailed test report."""
    print("\n📊 Detailed Test Report")
    print("=" * 60)
    
    successful_formats = [fmt for fmt, result in results.items() if result.get('success')]
    failed_formats = [fmt for fmt, result in results.items() if not result.get('success')]
    
    print(f"✅ Successful Formats: {len(successful_formats)}")
    for fmt in successful_formats:
        result = results[fmt]
        analysis = result.get('content_analysis', {})
        print(f"   - {fmt.upper()}:")
        print(f"     Content: {result['content_length']} chars")
        print(f"     Markdown: {result['markdown_length']} chars")
        print(f"     Type: {analysis.get('type', 'unknown')}")
        print(f"     Elements: {analysis.get('headers', 0)} headers, {analysis.get('lists', 0)} lists, {analysis.get('tables', 0)} tables")
    
    if failed_formats:
        print(f"\n❌ Failed Formats: {len(failed_formats)}")
        for fmt in failed_formats:
            result = results[fmt]
            print(f"   - {fmt.upper()}: {result.get('error', 'Unknown error')}")
    
    print(f"\n📈 Summary:")
    print(f"   Total formats tested: {len(results)}")
    print(f"   Success rate: {len(successful_formats)}/{len(results)} ({len(successful_formats)/len(results)*100:.1f}%)")
    
    if successful_formats:
        avg_content = sum(results[fmt]['content_length'] for fmt in successful_formats) / len(successful_formats)
        avg_markdown = sum(results[fmt]['markdown_length'] for fmt in successful_formats) / len(successful_formats)
        print(f"   Average content length: {avg_content:.0f} characters")
        print(f"   Average markdown length: {avg_markdown:.0f} characters")
        
        # Content type distribution
        content_types = {}
        for fmt in successful_formats:
            analysis = results[fmt].get('content_analysis', {})
            content_type = analysis.get('type', 'unknown')
            content_types[content_type] = content_types.get(content_type, 0) + 1
        
        print(f"   Content types: {content_types}")


def main():
    """Main test function."""
    print("🚀 Enhanced Real File Extraction Test")
    print("=" * 60)
    
    # Test file extraction
    results = test_file_extraction()
    
    # Test markdown quality
    test_markdown_quality()
    
    # Test LLM integration readiness
    test_llm_integration_ready()
    
    # Generate detailed report
    generate_detailed_report(results)
    
    print("\n" + "=" * 60)
    print("✅ Enhanced Real File Extraction Test Completed!")
    print("\n🎯 Key Findings:")
    print("- Library successfully extracts content from real files")
    print("- Markdown conversion maintains content structure")
    print("- Output is ready for LLM integration")
    print("- Handles various content types (documents, data, lists)")
    print("- Maintains formatting and structure in conversion")


if __name__ == "__main__":
    main()

==> docstrange-1.0.4.tar.gz: docstrange-1.0.4/tests/test_real_files_enhanced.py <==
#!/usr/bin/env python3
"""
Enhanced test script for downloading sample files and testing extraction capabilities.
Uses more reliable sample file sources and provides detailed analysis.
"""

import os
import tempfile
import requests
from docstrange import DocumentExtractor


def download_sample_files():
    """Download sample files for each supported format using reliable sources."""
    print("📥 Downloading sample files for testing...")
    
    samples = {}
    
    # More reliable sample URLs
    sample_urls = {
        'pdf': 'https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf',
        'csv': 'https://raw.githubusercontent.com/datasets/gdp/master/data/gdp.csv',
        'txt': 'https://www.gutenberg.org/files/1342/1342-0.txt',  # Pride and Prejudice
        'html': 'https://raw.githubusercontent.com/mdn/learning-area/master/html/introduction-to-html/getting-started/index.html',
    }
    
    for format_type, url in sample_urls.items():
        try:
            print(f"   Downloading {format_type.upper()} sample...")
            response = requests.get(url, timeout=30)
            response.raise_for_status()
            
            # Create temporary file
            with tempfile.NamedTemporaryFile(suffix=f'.{format_type}', delete=False) as f:
                f.write(response.content)
                samples[format_type] = f.name
            
            print(f"   ✅ Downloaded {format_type.upper()}: {len(response.content)} bytes")
            
        except Exception as e:
            print(f"   ❌ Failed to download {format_type.upper()}: {e}")
    
    return samples


def create_sample_files():
    """Create additional sample files for testing."""
    print("   Creating additional sample files...")
    
    samples = {}
    
    # Create sample DOCX-like content (simulated)
    with tempfile.NamedTemporaryFile(mode='w', suffix='.txt', delete=False) as f:
        f.write("""# Business Document

## Company Overview
Our company specializes in innovative solutions for modern businesses.

## Services
- Software Development
- Cloud Solutions
- AI Integration
- Data Analytics

## Contact Information
Email: contact@company.com
Phone: +1-555-0123
Address: 123 Business St, City, State 12345

## Financial Summary
| Quarter | Revenue | Growth |
|---------|---------|--------|
| Q1 | $1.2M | 15% |
| Q2 | $1.4M | 17% |
| Q3 | $1.6M | 14% |
| Q4 | $1.8M | 12% |
        """)
        samples['docx_sim'] = f.name
    
    # Create sample Excel-like content (CSV format)
    with tempfile.NamedTemporaryFile(mode='w', suffix='.csv', delete=False) as f:
        f.write("""Department,Employee,Salary,Start_Date
Engineering,John Smith,75000,2023-01-15
Marketing,Jane Doe,65000,2023-02-01
Sales,Bob Johnson,80000,2023-01-20
HR,Alice Brown,70000,2023-03-01
Finance,Charlie Wilson,85000,2023-02-15
IT,Sarah Davis,90000,2023-01-10
        """)
        samples['excel_sim'] = f.name
    
    # Create sample PowerPoint-like content
    with tempfile.NamedTemporaryFile(mode='w', suffix='.txt', delete=False) as f:
        f.write("""# Presentation: Q4 Business Review

## Slide 1: Executive Summary
- Revenue growth: 15% YoY
- Market expansion: 3 new regions
- Product launches: 2 successful releases

## Slide 2: Financial Performance
- Total revenue: $2.5M
- Profit margin: 23%
- Customer acquisition cost: $150

## Slide 3: Key Achievements
1. Launched mobile app
2. Expanded to Europe
3. Improved customer satisfaction
4. Reduced operational costs

## Slide 4: Next Steps
- Q1: Launch new product line
- Q2: Enter Asian markets
- Q3: AI integration rollout
- Q4: IPO preparation
        """)
        samples['pptx_sim'] = f.name
    
    return samples


def test_file_extraction():
    """Test extraction capabilities on downloaded and created files."""
    print("\n🧪 Testing File Extraction Capabilities")
    print("=" * 60)
    
    extractor = DocumentExtractor()
    
    # Get downloaded samples
    downloaded_samples = download_sample_files()
    
    # Get created samples
    created_samples = create_sample_files()
    
    # Combine all samples
    all_samples = {**downloaded_samples, **created_samples}
    
    results = {}
    
    for format_type, file_path in all_samples.items():
        print(f"\n📄 Testing {format_type.upper()} extraction...")
        
        try:
            # Test basic conversion
            result = extractor.extract(file_path)
            
            # Get markdown output
            markdown = result.extract_markdown()
            
            # Analyze content
            content_analysis = analyze_content(markdown)
            
            # Store results
            results[format_type] = {
                'success': True,
                'content_length': len(result.content),
                'markdown_length': len(markdown),
                'metadata_keys': list(result.metadata.keys()),
                'content_analysis': content_analysis,
                'preview': markdown[:300] + "..." if len(markdown) > 300 else markdown
            }
            
            print(f"   ✅ {format_type.upper()} extraction successful")
            print(f"      Content length: {len(result.content)} characters")
            print(f"      Markdown length: {len(markdown)} characters")
            print(f"      Metadata keys: {len(result.metadata)} items")
            print(f"      Content analysis: {content_analysis}")
            
            # Show preview
            print(f"      Preview: {markdown[:100]}...")
            
        except Exception as e:
            results[format_type] = {
                'success': False,
                'error': str(e)
            }
            print(f"   ❌ {format_type.upper()} extraction failed: {e}")
        
        finally:
            # Clean up file
            if os.path.exists(file_path):
                os.unlink(file_path)
    
    return results


def analyze_content(markdown_content):
    """Analyze the content structure of the markdown."""
    analysis = {}
    
    # Count different elements
    analysis['lines'] = len(markdown_content.split('\n'))
    analysis['words'] = len(markdown_content.split())
    analysis['headers'] = markdown_content.count('#')
    analysis['lists'] = markdown_content.count('- ') + markdown_content.count('* ')
    analysis['tables'] = markdown_content.count('|')
    analysis['links'] = markdown_content.count('[')
    
    # Determine content type
    if analysis['tables'] > 10:
        analysis['type'] = 'structured_data'
    elif analysis['headers'] > 5:
        analysis['type'] = 'document'
    elif analysis['lists'] > 5:
        analysis['type'] = 'list_content'
    else:
        analysis['type'] = 'text'
    
    return analysis


def test_markdown_quality():
    """Test the quality of markdown output."""
    print("\n📝 Testing Markdown Quality")
    print("=" * 60)
    
    extractor = DocumentExtractor()
    
    # Test with different content types
    test_contents = [
        ("Simple text", "This is a simple text document."),
        ("Text with headers", "# Header 1\n## Header 2\nThis is content."),
        ("Text with lists", "- Item 1\n- Item 2\n- Item 3"),
        ("Text with table", "| Col1 | Col2 |\n|------|------|\n| Data | Data |"),
    ]
    
    for content_name, content in test_contents:
        print(f"\n   Testing: {content_name}")
        
        try:
            result = extractor.extract_text(content)
            markdown = result.extract_markdown()
            
            print(f"      Original: {len(content)} chars")
            print(f"      Markdown: {len(markdown)} chars")
            print(f"      Quality: {'✅ Good' if markdown.strip() == content.strip() else '⚠️  Modified'}")
            
        except Exception as e:
            print(f"      ❌ Failed: {e}")


def test_llm_integration_ready():
    """Test if the output is ready for LLM integration."""
    print("\n🤖 Testing LLM Integration Readiness")
    print("=" * 60)
    
    extractor = DocumentExtractor()
    
    # Create a sample business document
    sample_doc = """# Quarterly Business Report

## Executive Summary
This report covers Q4 2024 performance and strategic initiatives.

## Financial Performance
- Revenue: $2.5M (15% increase)
- Profit Margin: 23%
- Customer Growth: 45%

## Key Metrics
| Metric | Q3 | Q4 | Growth |
|--------|----|----|--------|
| Revenue | $2.1M | $2.5M | 19% |
| Users | 15K | 22K | 47% |
| Retention | 85% | 89% | 4% |

## Recommendations
1. Expand marketing budget
2. Improve customer support
3. Launch new product line
    """
    
    try:
        result = extractor.extract_text(sample_doc)
        markdown = result.extract_markdown()
        
        print("   ✅ Document converted to LLM-ready format")
        print(f"   Content length: {len(markdown)} characters")
        
        # Test LLM integration example
        print("\n   📋 LLM Integration Example:")
        print("   ```python")
        print("   from litellm import completion")
        print("   ")
        print("   response = completion(")
        print("       model=\"openai/gpt-4o\",")
        print("       messages=[")
        print("           {\"role\": \"system\", \"content\": \"You are a business analyst.\"},")
        print("           {\"role\": \"user\", \"content\": f\"Analyze this report:\\n\\n{markdown}\"}")
        print("       ]")
        print("   )")
        print("   ")
        print("   print(response.choices[0].message.content)")
        print("   ```")
        
    except Exception as e:
        print(f"   ❌ LLM integration test failed: {e}")


def generate_detailed_report(results):
    """Generate a detailed test report."""
    print("\n📊 Detailed Test Report")
    print("=" * 60)
    
    successful_formats = [fmt for fmt, result in results.items() if result.get('success')]
    failed_formats = [fmt for fmt, result in results.items() if not result.get('success')]
    
    print(f"✅ Successful Formats: {len(successful_formats)}")
    for fmt in successful_formats:
        result = results[fmt]
        analysis = result.get('content_analysis', {})
        print(f"   - {fmt.upper()}:")
        print(f"     Content: {result['content_length']} chars")
        print(f"     Markdown: {result['markdown_length']} chars")
        print(f"     Type: {analysis.get('type', 'unknown')}")
        print(f"     Elements: {analysis.get('headers', 0)} headers, {analysis.get('lists', 0)} lists, {analysis.get('tables', 0)} tables")
    
    if failed_formats:
        print(f"\n❌ Failed Formats: {len(failed_formats)}")
        for fmt in failed_formats:
            result = results[fmt]
            print(f"   - {fmt.upper()}: {result.get('error', 'Unknown error')}")
    
    print(f"\n📈 Summary:")
    print(f"   Total formats tested: {len(results)}")
    print(f"   Success rate: {len(successful_formats)}/{len(results)} ({len(successful_formats)/len(results)*100:.1f}%)")
    
    if successful_formats:
        avg_content = sum(results[fmt]['content_length'] for fmt in successful_formats) / len(successful_formats)
        avg_markdown = sum(results[fmt]['markdown_length'] for fmt in successful_formats) / len(successful_formats)
        print(f"   Average content length: {avg_content:.0f} characters")
        print(f"   Average markdown length: {avg_markdown:.0f} characters")
        
        # Content type distribution
        content_types = {}
        for fmt in successful_formats:
            analysis = results[fmt].get('content_analysis', {})
            content_type = analysis.get('type', 'unknown')
            content_types[content_type] = content_types.get(content_type, 0) + 1
        
        print(f"   Content types: {content_types}")


def main():
    """Main test function."""
    print("🚀 Enhanced Real File Extraction Test")
    print("=" * 60)
    
    # Test file extraction
    results = test_file_extraction()
    
    # Test markdown quality
    test_markdown_quality()
    
    # Test LLM integration readiness
    test_llm_integration_ready()
    
    # Generate detailed report
    generate_detailed_report(results)
    
    print("\n" + "=" * 60)
    print("✅ Enhanced Real File Extraction Test Completed!")
    print("\n🎯 Key Findings:")
    print("- Library successfully extracts content from real files")
    print("- Markdown conversion maintains content structure")
    print("- Output is ready for LLM integration")
    print("- Handles various content types (documents, data, lists)")
    print("- Maintains formatting and structure in conversion")


if __name__ == "__main__":
    main()
